"""
    Routing API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_dss.psm.model.api_list_meta import ApiListMeta
from pensando_dss.psm.model.routing_neighbor import RoutingNeighbor
globals()['ApiListMeta'] = ApiListMeta
globals()['RoutingNeighbor'] = RoutingNeighbor
from pensando_dss.psm.psm.model.routing_neighbor_list import RoutingNeighborList


class TestRoutingNeighborList(unittest.TestCase):
    """RoutingNeighborList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testRoutingNeighborList(self):
        """Test RoutingNeighborList"""
        # FIXME: construct object with mandatory attributes with example values
        # model = RoutingNeighborList()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
